@@ -1,18 +1,15 @@
 package Fey;
-BEGIN {
-  $Fey::VERSION = '0.40';
-}
 
 use strict;
 use warnings;
 
-use Moose 0.90 ();
+our $VERSION = '0.41';
 
 1;
 
 # ABSTRACT: Better SQL Generation Through Perl
 
-
+__END__
 
 =pod
 
@@ -22,7 +19,7 @@ Fey - Better SQL Generation Through Perl
 
 =head1 VERSION
 
-version 0.40
+version 0.41
 
 =head1 SYNOPSIS
 
@@ -310,7 +307,7 @@ generating high-level application object classes which subclass the
 Alzabo classes and add "business logic" methods. This is what is
 provided by C<Alzabo::MethodMaker>.
 
-Nowadays, I prefer to have my business logic classes simple use the
+Nowadays, I prefer to have my business logic classes simply use the
 Alzabo classes. In other words, I now prefer "has-a" and "uses-a"
 versus "is-a" object design for this case.
 
@@ -405,16 +402,40 @@ your bug as I make changes.
 
 Dave Rolsky <autarch@urth.org>
 
+=head1 CONTRIBUTORS
+
+=for stopwords Aristotle Pagaltzis hdp@glaive.weftsoar.net hdp@localhost hdp@rook.opensourcery.com Oliver Charles
+
+=over 4
+
+=item *
+
+Aristotle Pagaltzis <pagaltzis@gmx.de>
+
+=item *
+
+hdp@glaive.weftsoar.net <hdp@glaive.weftsoar.net>
+
+=item *
+
+hdp@localhost <hdp@localhost>
+
+=item *
+
+hdp@rook.opensourcery.com <hdp@rook.opensourcery.com>
+
+=item *
+
+Oliver Charles <oliver@ocharles.org.uk>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2011 by Dave Rolsky.
+This software is Copyright (c) 2011 - 2015 by Dave Rolsky.
 
 This is free software, licensed under:
 
   The Artistic License 2.0 (GPL Compatible)
 
 =cut
-
-
-__END__
-
