@@ -1,12 +1,11 @@
 package Fey::Column;
-BEGIN {
-  $Fey::Column::VERSION = '0.40';
-}
 
 use strict;
 use warnings;
 use namespace::autoclean;
 
+our $VERSION = '0.41';
+
 use Scalar::Util qw( blessed weaken );
 
 use Fey::Column::Alias;
@@ -23,9 +22,9 @@ use Fey::Types qw(
     Str
 );
 
-use Moose;
-use MooseX::SemiAffordanceAccessor;
-use MooseX::StrictConstructor;
+use Moose 0.90;
+use MooseX::SemiAffordanceAccessor 0.03;
+use MooseX::StrictConstructor 0.07;
 
 with 'Fey::Role::ColumnLike';
 
@@ -175,7 +174,7 @@ __PACKAGE__->meta()->make_immutable();
 
 # ABSTRACT: Represents a column
 
-
+__END__
 
 =pod
 
@@ -185,7 +184,7 @@ Fey::Column - Represents a column
 
 =head1 VERSION
 
-version 0.40
+version 0.41
 
 =head1 SYNOPSIS
 
@@ -342,14 +341,10 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2011 by Dave Rolsky.
+This software is Copyright (c) 2011 - 2015 by Dave Rolsky.
 
 This is free software, licensed under:
 
   The Artistic License 2.0 (GPL Compatible)
 
 =cut
-
-
-__END__
-
