@@ -1,21 +1,19 @@
 package Fey::Column::Alias;
-BEGIN {
-  $Fey::Column::Alias::VERSION = '0.40';
-}
 
 use strict;
 use warnings;
 use namespace::autoclean;
 
-use Fey::Column;
+our $VERSION = '0.41';
+
 use Fey::Exceptions qw( object_state_error );
 use Fey::Table;
 use Fey::Table::Alias;
 use Fey::Types qw( Column Str );
 
-use Moose;
-use MooseX::SemiAffordanceAccessor;
-use MooseX::StrictConstructor;
+use Moose 0.90;
+use MooseX::SemiAffordanceAccessor 0.03;
+use MooseX::StrictConstructor 0.07;
 
 with 'Fey::Role::ColumnLike';
 
@@ -89,11 +87,14 @@ sub _build_id {
 
 __PACKAGE__->meta()->make_immutable();
 
+# This is here to avoid a circular use issue.
+require Fey::Column;
+
 1;
 
 # ABSTRACT: Represents an alias for a column
 
-
+__END__
 
 =pod
 
@@ -103,7 +104,7 @@ Fey::Column::Alias - Represents an alias for a column
 
 =head1 VERSION
 
-version 0.40
+version 0.41
 
 =head1 SYNOPSIS
 
@@ -197,14 +198,10 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2011 by Dave Rolsky.
+This software is Copyright (c) 2011 - 2015 by Dave Rolsky.
 
 This is free software, licensed under:
 
   The Artistic License 2.0 (GPL Compatible)
 
 =cut
-
-
-__END__
-
