@@ -1,12 +1,11 @@
 package Fey::Literal;
-BEGIN {
-  $Fey::Literal::VERSION = '0.40';
-}
 
 use strict;
 use warnings;
 use namespace::autoclean;
 
+our $VERSION = '0.41';
+
 use Fey::FakeDBI;
 use Fey::Literal::Function;
 use Fey::Literal::Null;
@@ -20,9 +19,9 @@ use overload ();
 # This needs to come before we load subclasses or shit blows up
 # because we end up with a metaclass object that is a
 # Class::MOP::Class, not Moose::Meta::Class.
-use Moose;
-use MooseX::SemiAffordanceAccessor;
-use MooseX::StrictConstructor;
+use Moose 0.90;
+use MooseX::SemiAffordanceAccessor 0.03;
+use MooseX::StrictConstructor 0.07;
 
 sub new_from_scalar {
     shift;
@@ -56,7 +55,7 @@ __PACKAGE__->meta()->make_immutable();
 
 # ABSTRACT: Factory for making a literal piece of a SQL statement
 
-
+__END__
 
 =pod
 
@@ -66,7 +65,7 @@ Fey::Literal - Factory for making a literal piece of a SQL statement
 
 =head1 VERSION
 
-version 0.40
+version 0.41
 
 =head1 SYNOPSIS
 
@@ -98,14 +97,10 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2011 by Dave Rolsky.
+This software is Copyright (c) 2011 - 2015 by Dave Rolsky.
 
 This is free software, licensed under:
 
   The Artistic License 2.0 (GPL Compatible)
 
 =cut
-
-
-__END__
-
