@@ -1,18 +1,17 @@
 package Fey::NamedObjectSet;
-BEGIN {
-  $Fey::NamedObjectSet::VERSION = '0.40';
-}
 
 use strict;
 use warnings;
 use namespace::autoclean;
 
+our $VERSION = '0.41';
+
 use List::AllUtils qw( all pairwise );
 use Tie::IxHash;
 
 use Fey::Types qw( HashRef Named );
 
-use Moose;
+use Moose 0.90;
 
 has '_set' => (
     is      => 'bare',
