@@ -1,12 +1,11 @@
 package Fey::Role::ColumnLike;
-BEGIN {
-  $Fey::Role::ColumnLike::VERSION = '0.40';
-}
 
 use strict;
 use warnings;
 use namespace::autoclean;
 
+our $VERSION = '0.41';
+
 use Moose::Role;
 
 # This seems weird, but basically we're saying that column-like things
@@ -39,7 +38,7 @@ sub is_orderable { return $_[0]->table() ? 1 : 0 }
 
 # ABSTRACT: A role for "column-like" behavior
 
-
+__END__
 
 =pod
 
@@ -49,11 +48,11 @@ Fey::Role::ColumnLike - A role for "column-like" behavior
 
 =head1 VERSION
 
-version 0.40
+version 0.41
 
 =head1 SYNOPSIS
 
-  use Moose;
+  use Moose 0.90;
 
   with 'Fey::Role::ColumnLike';
 
@@ -94,14 +93,10 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2011 by Dave Rolsky.
+This software is Copyright (c) 2011 - 2015 by Dave Rolsky.
 
 This is free software, licensed under:
 
   The Artistic License 2.0 (GPL Compatible)
 
 =cut
-
-
-__END__
-
