@@ -1,12 +1,11 @@
 package Fey::Role::Groupable;
-BEGIN {
-  $Fey::Role::Groupable::VERSION = '0.40';
-}
 
 use strict;
 use warnings;
 use namespace::autoclean;
 
+our $VERSION = '0.41';
+
 use Moose::Role;
 
 sub is_groupable {1}
@@ -15,7 +14,7 @@ sub is_groupable {1}
 
 # ABSTRACT: A role for things that can be part of a GROUP BY clause
 
-
+__END__
 
 =pod
 
@@ -25,11 +24,11 @@ Fey::Role::Groupable - A role for things that can be part of a GROUP BY clause
 
 =head1 VERSION
 
-version 0.40
+version 0.41
 
 =head1 SYNOPSIS
 
-  use Moose;
+  use Moose 0.90;
 
   with 'Fey::Role::Groupable';
 
@@ -56,14 +55,10 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2011 by Dave Rolsky.
+This software is Copyright (c) 2011 - 2015 by Dave Rolsky.
 
 This is free software, licensed under:
 
   The Artistic License 2.0 (GPL Compatible)
 
 =cut
-
-
-__END__
-
