@@ -1,15 +1,14 @@
 package Fey::Role::HasAliasName;
-BEGIN {
-  $Fey::Role::HasAliasName::VERSION = '0.40';
-}
 
 use strict;
 use warnings;
 use namespace::autoclean;
 
+our $VERSION = '0.41';
+
 use Fey::Types qw( Bool Str );
 
-use MooseX::Role::Parameterized;
+use MooseX::Role::Parameterized 0.04;
 
 parameter 'generated_alias_prefix' => (
     isa      => Str,
@@ -78,7 +77,7 @@ role {
 
 # ABSTRACT: A role for objects that bring an alias with them
 
-
+__END__
 
 =pod
 
@@ -88,13 +87,13 @@ Fey::Role::HasAliasName - A role for objects that bring an alias with them
 
 =head1 VERSION
 
-version 0.40
+version 0.41
 
 =head1 SYNOPSIS
 
   package My::Thing;
 
-  use Moose;
+  use Moose 0.90;
   with 'Fey::Role::HasAliasName'
       => { generated_alias_prefix => 'THING' };
 
@@ -151,14 +150,10 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2011 by Dave Rolsky.
+This software is Copyright (c) 2011 - 2015 by Dave Rolsky.
 
 This is free software, licensed under:
 
   The Artistic License 2.0 (GPL Compatible)
 
 =cut
-
-
-__END__
-
