@@ -1,12 +1,11 @@
 package Fey::Role::IsLiteral;
-BEGIN {
-  $Fey::Role::IsLiteral::VERSION = '0.40';
-}
 
 use strict;
 use warnings;
 use namespace::autoclean;
 
+our $VERSION = '0.41';
+
 use Moose::Role;
 
 requires 'sql';
@@ -19,7 +18,7 @@ sub id {
 
 # ABSTRACT: A role for things that are literals
 
-
+__END__
 
 =pod
 
@@ -29,11 +28,11 @@ Fey::Role::IsLiteral - A role for things that are literals
 
 =head1 VERSION
 
-version 0.40
+version 0.41
 
 =head1 SYNOPSIS
 
-  use Moose;
+  use Moose 0.90;
 
   with 'Fey::Role::IsLiteral';
 
@@ -52,14 +51,10 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2011 by Dave Rolsky.
+This software is Copyright (c) 2011 - 2015 by Dave Rolsky.
 
 This is free software, licensed under:
 
   The Artistic License 2.0 (GPL Compatible)
 
 =cut
-
-
-__END__
-
