@@ -1,15 +1,14 @@
 package Fey::Role::MakesAliasObjects;
-BEGIN {
-  $Fey::Role::MakesAliasObjects::VERSION = '0.40';
-}
 
 use strict;
 use warnings;
 use namespace::autoclean;
 
+our $VERSION = '0.41';
+
 use Fey::Types qw( ClassName Str );
 
-use MooseX::Role::Parameterized;
+use MooseX::Role::Parameterized 0.04;
 
 parameter 'alias_class' => (
     is       => 'ro',
@@ -48,7 +47,7 @@ role {
 
 # ABSTRACT: A role for objects with separate alias objects
 
-
+__END__
 
 =pod
 
@@ -58,13 +57,13 @@ Fey::Role::MakesAliasObjects - A role for objects with separate alias objects
 
 =head1 VERSION
 
-version 0.40
+version 0.41
 
 =head1 SYNOPSIS
 
   package My::Thing;
 
-  use Moose;
+  use Moose 0.90;
 
   with 'Fey::Role::MakesAliasObjects'
       => { alias_class => 'My::Alias',
@@ -116,14 +115,10 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2011 by Dave Rolsky.
+This software is Copyright (c) 2011 - 2015 by Dave Rolsky.
 
 This is free software, licensed under:
 
   The Artistic License 2.0 (GPL Compatible)
 
 =cut
-
-
-__END__
-
