@@ -1,12 +1,11 @@
 package Fey::Role::SQL::HasBindParams;
-BEGIN {
-  $Fey::Role::SQL::HasBindParams::VERSION = '0.40';
-}
 
 use strict;
 use warnings;
 use namespace::autoclean;
 
+our $VERSION = '0.41';
+
 use Fey::Types qw( ArrayRef Bool );
 
 use Moose::Role;
@@ -36,7 +35,7 @@ sub bind_params {
 
 # ABSTRACT: A role for queries which can have bind parameters
 
-
+__END__
 
 =pod
 
@@ -46,11 +45,11 @@ Fey::Role::SQL::HasBindParams - A role for queries which can have bind parameter
 
 =head1 VERSION
 
-version 0.40
+version 0.41
 
 =head1 SYNOPSIS
 
-  use Moose;
+  use Moose 0.90;
 
   with 'Fey::Role::SQL::HasBindParams';
 
@@ -82,14 +81,10 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2011 by Dave Rolsky.
+This software is Copyright (c) 2011 - 2015 by Dave Rolsky.
 
 This is free software, licensed under:
 
   The Artistic License 2.0 (GPL Compatible)
 
 =cut
-
-
-__END__
-
