@@ -1,18 +1,17 @@
 package Fey::Role::SQL::HasLimitClause;
-BEGIN {
-  $Fey::Role::SQL::HasLimitClause::VERSION = '0.40';
-}
 
 use strict;
 use warnings;
 use namespace::autoclean;
 
+our $VERSION = '0.41';
+
 use Scalar::Util qw( blessed );
 
 use Fey::Types qw( PosInteger PosOrZeroInteger Undef );
 
 use Moose::Role;
-use MooseX::Params::Validate qw( pos_validated_list );
+use MooseX::Params::Validate 0.08 qw( pos_validated_list );
 
 has '_limit' => (
     is        => 'rw',
@@ -30,7 +29,7 @@ sub limit {
     my $self = shift;
     my ( $limit, $offset ) = pos_validated_list(
         \@_,
-        { isa => (PosInteger | Undef) },
+        { isa => ( PosInteger | Undef ) },
         {
             isa      => PosOrZeroInteger,
             optional => 1,
@@ -66,7 +65,7 @@ sub limit_clause {
 
 # ABSTRACT: A role for queries which can include a LIMIT clause
 
-
+__END__
 
 =pod
 
@@ -76,11 +75,11 @@ Fey::Role::SQL::HasLimitClause - A role for queries which can include a LIMIT cl
 
 =head1 VERSION
 
-version 0.40
+version 0.41
 
 =head1 SYNOPSIS
 
-  use Moose;
+  use Moose 0.90;
 
   with 'Fey::Role::SQL::HasLimitClause';
 
@@ -112,14 +111,10 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2011 by Dave Rolsky.
+This software is Copyright (c) 2011 - 2015 by Dave Rolsky.
 
 This is free software, licensed under:
 
   The Artistic License 2.0 (GPL Compatible)
 
 =cut
-
-
-__END__
-
