@@ -1,17 +1,16 @@
 package Fey::Role::SQL::HasOrderByClause;
-BEGIN {
-  $Fey::Role::SQL::HasOrderByClause::VERSION = '0.40';
-}
 
 use strict;
 use warnings;
 use namespace::autoclean;
 
+our $VERSION = '0.41';
+
 use Fey::Types qw( ArrayRef OrderByElement );
 use Scalar::Util qw( blessed );
 
 use Moose::Role;
-use MooseX::Params::Validate qw( pos_validated_list );
+use MooseX::Params::Validate 0.08 qw( pos_validated_list );
 
 has '_order_by' => (
     traits  => ['Array'],
@@ -68,7 +67,7 @@ sub order_by_clause {
 
 # ABSTRACT: A role for queries which can include a ORDER BY clause
 
-
+__END__
 
 =pod
 
@@ -78,11 +77,11 @@ Fey::Role::SQL::HasOrderByClause - A role for queries which can include a ORDER
 
 =head1 VERSION
 
-version 0.40
+version 0.41
 
 =head1 SYNOPSIS
 
-  use Moose;
+  use Moose 0.90;
 
   with 'Fey::Role::SQL::HasOrderByClause';
 
@@ -115,14 +114,10 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2011 by Dave Rolsky.
+This software is Copyright (c) 2011 - 2015 by Dave Rolsky.
 
 This is free software, licensed under:
 
   The Artistic License 2.0 (GPL Compatible)
 
 =cut
-
-
-__END__
-
