@@ -1,12 +1,11 @@
 package Fey::Role::SQL::ReturnsData;
-BEGIN {
-  $Fey::Role::SQL::ReturnsData::VERSION = '0.40';
-}
 
 use strict;
 use warnings;
 use namespace::autoclean;
 
+our $VERSION = '0.41';
+
 use Moose::Role;
 
 # This doesn't actually work with Fey::Role::SetOperation in the mix.
@@ -16,7 +15,7 @@ use Moose::Role;
 
 # ABSTRACT: A role for SQL queries which return data (SELECT, UNION, etc)
 
-
+__END__
 
 =pod
 
@@ -26,11 +25,11 @@ Fey::Role::SQL::ReturnsData - A role for SQL queries which return data (SELECT,
 
 =head1 VERSION
 
-version 0.40
+version 0.41
 
 =head1 SYNOPSIS
 
-  use Moose;
+  use Moose 0.90;
 
   with 'Fey::Role::ReturnsData';
 
@@ -55,14 +54,10 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2011 by Dave Rolsky.
+This software is Copyright (c) 2011 - 2015 by Dave Rolsky.
 
 This is free software, licensed under:
 
   The Artistic License 2.0 (GPL Compatible)
 
 =cut
-
-
-__END__
-
