@@ -1,21 +1,22 @@
 package Fey::Role::TableLike;
-BEGIN {
-  $Fey::Role::TableLike::VERSION = '0.40';
-}
 
 use strict;
 use warnings;
 use namespace::autoclean;
 
+our $VERSION = '0.41';
+
 use Moose::Role;
 
 with 'Fey::Role::Joinable';
 
+requires 'sql_for_select_clause';
+
 1;
 
 # ABSTRACT: A role for things that are like a table
 
-
+__END__
 
 =pod
 
@@ -25,11 +26,11 @@ Fey::Role::TableLike - A role for things that are like a table
 
 =head1 VERSION
 
-version 0.40
+version 0.41
 
 =head1 SYNOPSIS
 
-  use Moose;
+  use Moose 0.90;
 
   with 'Fey::Role::TableLike';
 
@@ -48,14 +49,10 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2011 by Dave Rolsky.
+This software is Copyright (c) 2011 - 2015 by Dave Rolsky.
 
 This is free software, licensed under:
 
   The Artistic License 2.0 (GPL Compatible)
 
 =cut
-
-
-__END__
-
