@@ -1,11 +1,10 @@
 package Fey::SQL;
-BEGIN {
-  $Fey::SQL::VERSION = '0.40';
-}
 
 use strict;
 use warnings;
 
+our $VERSION = '0.41';
+
 use Fey::SQL::Delete;
 use Fey::SQL::Insert;
 use Fey::SQL::Select;
@@ -60,7 +59,7 @@ sub new_except {
 
 # ABSTRACT: Documentation on SQL generation with Fey and SQL object factory
 
-
+__END__
 
 =pod
 
@@ -70,7 +69,7 @@ Fey::SQL - Documentation on SQL generation with Fey and SQL object factory
 
 =head1 VERSION
 
-version 0.40
+version 0.41
 
 =head1 SYNOPSIS
 
@@ -243,12 +242,12 @@ types of things:
 
 =item * An object which has an C<is_comparable()> method that returns true
 
-This includes objects which do the L<Fey::ColumnLike> role: L<Fey::Column> and
-L<Fey::Column::Alias>. A column only returns true for C<is_comparable()> when
-it is actually attached to a table.
+This includes objects which do the L<Fey::Role::ColumnLike> role:
+L<Fey::Column> and L<Fey::Column::Alias>. A column only returns true for
+C<is_comparable()> when it is actually attached to a table.
 
-Objects which do the L<Fey::Role::Comaprable> role: L<Fey::SQL::Select>,
-L<Fey::SQL::Union>, L<Fey::SQL::Intersection>, and L<Fey::SQL::Except> always
+Objects which do the L<Fey::Role::Comparable> role: L<Fey::SQL::Select>,
+L<Fey::SQL::Union>, L<Fey::SQL::Intersect>, and L<Fey::SQL::Except> always
 return true for C<is_comparable()>.
 
 If you try to compare something to something that returns a data set, you must
@@ -285,9 +284,9 @@ You can pass the strings "(" and ")" to the C<where()> method in order
 to create subgroups.
 
   # WHERE Part.size > 10
-  #   AND ( User.name = 'Widget'
+  #   AND ( Part.name = 'Widget'
   #         OR
-  #         User.name = 'Grommit' )
+  #         Part.name = 'Grommit' )
   $sql->where( $size, '>', 10 );
   $sql->where( '(' );
   $sql->where( $name, '=', 'Widget' );
@@ -402,14 +401,10 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2011 by Dave Rolsky.
+This software is Copyright (c) 2011 - 2015 by Dave Rolsky.
 
 This is free software, licensed under:
 
   The Artistic License 2.0 (GPL Compatible)
 
 =cut
-
-
-__END__
-
