@@ -1,13 +1,12 @@
 package Fey::SQL::Except;
-BEGIN {
-  $Fey::SQL::Except::VERSION = '0.40';
-}
 
 use strict;
 use warnings;
 use namespace::autoclean;
 
-use Moose;
+our $VERSION = '0.41';
+
+use Moose 0.90;
 
 with 'Fey::Role::SetOperation' => { keyword => 'EXCEPT' };
 
@@ -17,8 +16,8 @@ with 'Fey::Role::SQL::Cloneable';
 
 # ABSTRACT: Represents an EXCEPT operation
 
-
 __END__
+
 =pod
 
 =head1 NAME
@@ -27,7 +26,7 @@ Fey::SQL::Except - Represents an EXCEPT operation
 
 =head1 VERSION
 
-version 0.40
+version 0.41
 
 =head1 SYNOPSIS
 
@@ -73,11 +72,10 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2011 by Dave Rolsky.
+This software is Copyright (c) 2011 - 2015 by Dave Rolsky.
 
 This is free software, licensed under:
 
   The Artistic License 2.0 (GPL Compatible)
 
 =cut
-
