@@ -1,17 +1,17 @@
 package Fey::SQL::Fragment::Join;
-BEGIN {
-  $Fey::SQL::Fragment::Join::VERSION = '0.40';
-}
 
 use strict;
 use warnings;
 use namespace::autoclean;
 
+our $VERSION = '0.41';
+
+use Fey::Exceptions qw( param_error );
 use Fey::FakeDBI;
 use Fey::Types qw( FK OuterJoinType Table WhereClause );
 use List::AllUtils qw( pairwise );
 
-use Moose;
+use Moose 0.90;
 
 has '_table1' => (
     is       => 'ro',
@@ -28,9 +28,10 @@ has '_table2' => (
 );
 
 has '_fk' => (
-    is       => 'ro',
-    isa      => FK,
-    init_arg => 'fk',
+    is        => 'ro',
+    isa       => FK,
+    init_arg  => 'fk',
+    predicate => '_has_fk',
 );
 
 has '_outer_type' => (
@@ -47,6 +48,15 @@ has '_where' => (
     init_arg  => 'where',
 );
 
+sub BUILD {
+    my $self = shift;
+
+    param_error 'You cannot join two tables without a foreign key'
+        if $self->_has_table2() && !$self->_has_fk();
+
+    return;
+}
+
 sub id {
     my $self = shift;
 
@@ -195,7 +205,7 @@ __PACKAGE__->meta()->make_immutable();
 
 # ABSTRACT: Represents a single join in a FROM clause
 
-
+__END__
 
 =pod
 
@@ -205,7 +215,7 @@ Fey::SQL::Fragment::Join - Represents a single join in a FROM clause
 
 =head1 VERSION
 
-version 0.40
+version 0.41
 
 =head1 DESCRIPTION
 
@@ -225,14 +235,10 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2011 by Dave Rolsky.
+This software is Copyright (c) 2011 - 2015 by Dave Rolsky.
 
 This is free software, licensed under:
 
   The Artistic License 2.0 (GPL Compatible)
 
 =cut
-
-
-__END__
-
