@@ -1,15 +1,14 @@
 package Fey::SQL::Fragment::Where::Boolean;
-BEGIN {
-  $Fey::SQL::Fragment::Where::Boolean::VERSION = '0.40';
-}
 
 use strict;
 use warnings;
 use namespace::autoclean;
 
+our $VERSION = '0.41';
+
 use Fey::Types qw( WhereBoolean );
 
-use Moose;
+use Moose 0.90;
 
 has 'comparison' => (
     is       => 'ro',
@@ -27,7 +26,7 @@ __PACKAGE__->meta()->make_immutable();
 
 # ABSTRACT: Represents an AND or OR in a WHERE clause
 
-
+__END__
 
 =pod
 
@@ -37,7 +36,7 @@ Fey::SQL::Fragment::Where::Boolean - Represents an AND or OR in a WHERE clause
 
 =head1 VERSION
 
-version 0.40
+version 0.41
 
 =head1 DESCRIPTION
 
@@ -56,14 +55,10 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2011 by Dave Rolsky.
+This software is Copyright (c) 2011 - 2015 by Dave Rolsky.
 
 This is free software, licensed under:
 
   The Artistic License 2.0 (GPL Compatible)
 
 =cut
-
-
-__END__
-
