@@ -1,19 +1,18 @@
 package Fey::SQL::Fragment::Where::Comparison;
-BEGIN {
-  $Fey::SQL::Fragment::Where::Comparison::VERSION = '0.40';
-}
 
 use strict;
 use warnings;
 use namespace::autoclean;
 
+our $VERSION = '0.41';
+
 use Fey::Exceptions qw( param_error );
 use Fey::Literal;
 use Fey::Placeholder;
 use Fey::Types qw( ArrayRef WhereClauseSide Str );
 use Scalar::Util qw( blessed );
 
-use Moose;
+use Moose 0.90;
 
 has '_lhs' => (
     is       => 'ro',
@@ -29,7 +28,7 @@ has '_operator' => (
 
 has '_rhs' => (
     is       => 'ro',
-    isa      => ArrayRef[WhereClauseSide],
+    isa      => ArrayRef [WhereClauseSide],
     required => 1,
 );
 
@@ -92,7 +91,7 @@ sub BUILDARGS {
             unless $operator =~ /$eq_comp_re|$in_comp_re/;
     }
 
-    if ( lc $operator eq 'between' ) {
+    if ( defined $operator && lc $operator eq 'between' ) {
         param_error "The BETWEEN operator requires two arguments"
             unless @rhs == 2;
     }
@@ -173,7 +172,7 @@ __PACKAGE__->meta()->make_immutable();
 
 # ABSTRACT: Represents a comparison in a WHERE clause
 
-
+__END__
 
 =pod
 
@@ -183,7 +182,7 @@ Fey::SQL::Fragment::Where::Comparison - Represents a comparison in a WHERE claus
 
 =head1 VERSION
 
-version 0.40
+version 0.41
 
 =head1 DESCRIPTION
 
@@ -202,14 +201,10 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2011 by Dave Rolsky.
+This software is Copyright (c) 2011 - 2015 by Dave Rolsky.
 
 This is free software, licensed under:
 
   The Artistic License 2.0 (GPL Compatible)
 
 =cut
-
-
-__END__
-
