@@ -1,13 +1,12 @@
 package Fey::SQL::Fragment::Where::SubgroupEnd;
-BEGIN {
-  $Fey::SQL::Fragment::Where::SubgroupEnd::VERSION = '0.40';
-}
 
 use strict;
 use warnings;
 use namespace::autoclean;
 
-use Moose;
+our $VERSION = '0.41';
+
+use Moose 0.90;
 
 my $Paren = ')';
 
@@ -21,7 +20,7 @@ __PACKAGE__->meta()->make_immutable();
 
 # ABSTRACT: Represents the end of a subgroup in a WHERE clause
 
-
+__END__
 
 =pod
 
@@ -31,7 +30,7 @@ Fey::SQL::Fragment::Where::SubgroupEnd - Represents the end of a subgroup in a W
 
 =head1 VERSION
 
-version 0.40
+version 0.41
 
 =head1 DESCRIPTION
 
@@ -50,14 +49,10 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2011 by Dave Rolsky.
+This software is Copyright (c) 2011 - 2015 by Dave Rolsky.
 
 This is free software, licensed under:
 
   The Artistic License 2.0 (GPL Compatible)
 
 =cut
-
-
-__END__
-
