@@ -1,22 +1,21 @@
 package Fey::SQL::Insert;
-BEGIN {
-  $Fey::SQL::Insert::VERSION = '0.40';
-}
 
 use strict;
 use warnings;
 use namespace::autoclean;
 
+our $VERSION = '0.41';
+
 use Fey::Types
     qw( ArrayRef HashRef CanQuote IntoElement NonNullableInsertValue
-        NullableInsertValue );
+    NullableInsertValue );
 use overload ();
 use Scalar::Util qw( blessed );
 
-use Moose;
-use MooseX::Params::Validate qw( validated_hash pos_validated_list );
-use MooseX::SemiAffordanceAccessor;
-use MooseX::StrictConstructor;
+use Moose 0.90;
+use MooseX::Params::Validate 0.08 qw( validated_hash pos_validated_list );
+use MooseX::SemiAffordanceAccessor 0.03;
+use MooseX::StrictConstructor 0.07;
 
 with 'Fey::Role::SQL::HasBindParams';
 
@@ -35,7 +34,7 @@ has '_values_spec' => (
 has '_values' => (
     traits  => ['Array'],
     is      => 'bare',
-    isa     => ArrayRef[HashRef],
+    isa     => ArrayRef [HashRef],
     default => sub { [] },
     handles => {
         _add_values => 'push',
@@ -166,7 +165,7 @@ sub values_clause {
                     && $val->does('Fey::Role::SQL::ReturnsData')
                     ? "($sql)"
                     : $sql
-                } @cols
+            } @cols
         );
 
         $v .= ')';
@@ -183,7 +182,7 @@ __PACKAGE__->meta()->make_immutable();
 
 # ABSTRACT: Represents a INSERT query
 
-
+__END__
 
 =pod
 
@@ -193,7 +192,7 @@ Fey::SQL::Insert - Represents a INSERT query
 
 =head1 VERSION
 
-version 0.40
+version 0.41
 
 =head1 SYNOPSIS
 
@@ -308,14 +307,10 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2011 by Dave Rolsky.
+This software is Copyright (c) 2011 - 2015 by Dave Rolsky.
 
 This is free software, licensed under:
 
   The Artistic License 2.0 (GPL Compatible)
 
 =cut
-
-
-__END__
-
