@@ -1,12 +1,11 @@
 package Fey::SQL::Select;
-BEGIN {
-  $Fey::SQL::Select::VERSION = '0.40';
-}
 
 use strict;
 use warnings;
 use namespace::autoclean;
 
+our $VERSION = '0.41';
+
 use Fey::Exceptions qw( param_error );
 use Fey::Literal;
 use Fey::Role::ColumnLike;
@@ -16,10 +15,10 @@ use Fey::Types
 use List::AllUtils qw( all );
 use Scalar::Util qw( blessed );
 
-use Moose;
-use MooseX::Params::Validate qw( pos_validated_list );
-use MooseX::SemiAffordanceAccessor;
-use MooseX::StrictConstructor;
+use Moose 0.90;
+use MooseX::Params::Validate 0.08 qw( pos_validated_list );
+use MooseX::SemiAffordanceAccessor 0.03;
+use MooseX::StrictConstructor 0.07;
 
 with 'Fey::Role::Comparable',
     'Fey::Role::Selectable',
@@ -117,15 +116,9 @@ sub select {
         MX_PARAMS_VALIDATE_NO_CACHE => 1,
     );
 
-    for my $elt (
-        map {
-            $_->can('columns')
-                ? sort { $a->name() cmp $b->name() } $_->columns()
-                : $_
-        }
-        map { blessed $_ ? $_ : Fey::Literal->new_from_scalar($_) } @select
-        ) {
-        $self->_add_select_element($elt);
+    for my $elt (@select) {
+        $self->_add_select_element(
+            blessed $elt ? $elt : Fey::Literal->new_from_scalar($elt) );
     }
 
     return $self;
@@ -160,34 +153,52 @@ sub from {
     my $is_inner_join = @_ >= 2 && !$is_outer_join;
 
     # gee, wouldn't multimethods be nice here?
+
+    #<<<
     my $meth = (
         @_ == 1
             && blessed $_[0]
             && $_[0]->can('is_joinable')
             && $_[0]->is_joinable()
-        ? '_from_one_table'
+          ? '_from_one_table'
+
         : @_ == 1
             && blessed $_[0]
             && $_[0]->can('does')
             && $_[0]->does('Fey::Role::SQL::ReturnsData')
-        ? '_from_subselect'
+          ? '_from_subselect'
 
         : $is_inner_join
-            && @_ == 4 && $_[3]->isa('Fey::SQL::Where') ? '_join_with_where'
+            && @_ == 4 && $_[3]->isa('Fey::SQL::Where')
+          ? '_join_with_where'
+
         : $is_inner_join
-            && @_ == 3 && $_[2]->isa('Fey::SQL::Where') ? '_join_with_where'
-        : $is_inner_join && @_ == 3 && $_[2]->isa('Fey::FK') ? '_join'
-        : $is_inner_join && @_ == 2 ? '_join'
+            && @_ == 3 && $_[2]->isa('Fey::SQL::Where')
+          ? '_join_with_where'
+
+        : $is_inner_join && @_ == 3 && $_[2]->isa('Fey::FK')
+          ? '_join'
+
+        : $is_inner_join && @_ == 2
+          ? '_join'
+
+        : $is_outer_join && @_ == 5
+          ? '_outer_join_with_where'
 
-        : $is_outer_join && @_ == 5 ? '_outer_join_with_where'
         : $is_outer_join
             && @_ == 4
-            && $_[3]->isa('Fey::SQL::Where') ? '_outer_join_with_where'
-        : $is_outer_join && @_ == 4 && $_[3]->isa('Fey::FK') ? '_outer_join'
-        : $is_outer_join && @_ == 3 ? '_outer_join'
+            && $_[3]->isa('Fey::SQL::Where')
+          ? '_outer_join_with_where'
+
+        : $is_outer_join && @_ == 4 && $_[3]->isa('Fey::FK')
+           ? '_outer_join'
+
+        : $is_outer_join && @_ == 3
+          ? '_outer_join'
 
         : undef
     );
+    #>>>
 
     param_error "from() called with invalid parameters (@_)."
         unless $meth;
@@ -248,7 +259,7 @@ sub _check_join_arguments {
         'the first two arguments to from() were not valid (not tables or something else joinable).'
         unless
         all { blessed $_ && $_->can('is_joinable') && $_->is_joinable() }
-        @_[ 0, 1 ];
+    @_[ 0, 1 ];
 }
 
 sub _fk_for_join {
@@ -324,9 +335,9 @@ sub _check_outer_join_arguments {
 
     param_error 'from() was called with invalid arguments'
         unless $_[0]->can('is_joinable')
-            && $_[0]->is_joinable()
-            && $_[2]->can('is_joinable')
-            && $_[2]->is_joinable();
+        && $_[0]->is_joinable()
+        && $_[2]->can('is_joinable')
+        && $_[2]->is_joinable();
 }
 
 sub group_by {
@@ -388,7 +399,11 @@ sub select_clause {
 
     $sql .= (
         join ', ',
-        map { $_->sql_with_alias($dbh) } $self->select_clause_elements()
+        map {
+                  $_->can('sql_for_select_clause')
+                ? $_->sql_for_select_clause($dbh)
+                : $_->sql_with_alias($dbh)
+        } $self->select_clause_elements()
     );
 
     return $sql;
@@ -402,8 +417,7 @@ sub from_clause {
 
     my %seen;
 
-    # We lower case  the test for correctly skipping
-    # already-seen tables.
+    # We lower case the test for correctly skipping already-seen tables.
     for my $frag (
         $self->_get_from( sort { lc($a) cmp lc($b) } $self->_from_ids() ) ) {
         my $join_sql = $frag->sql_with_alias( $dbh, \%seen );
@@ -474,9 +488,9 @@ sub bind_params {
 
     return (
         (
-            map { $_->bind_params() }
-            grep { $_->can('bind_params') }
-            $self->select_clause_elements()
+            map      { $_->bind_params() }
+                grep { $_->can('bind_params') }
+                $self->select_clause_elements()
         ),
 
         (
@@ -501,7 +515,7 @@ __PACKAGE__->meta()->make_immutable();
 
 # ABSTRACT: Represents a SELECT query
 
-
+__END__
 
 =pod
 
@@ -511,7 +525,7 @@ Fey::SQL::Select - Represents a SELECT query
 
 =head1 VERSION
 
-version 0.40
+version 0.41
 
 =head1 SYNOPSIS
 
@@ -560,7 +574,7 @@ These will be passed to C<< Fey::Literal->new_from_scalar() >>.
 =item * C<Fey::Table> objects
 
 If a table is passed, then all of its columns will be included in the
-C<SELECT> clause, sorted alphanumerically.
+C<SELECT> clause.
 
 =item * C<Fey::Column> objects, and aliases
 
@@ -817,14 +831,10 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2011 by Dave Rolsky.
+This software is Copyright (c) 2011 - 2015 by Dave Rolsky.
 
 This is free software, licensed under:
 
   The Artistic License 2.0 (GPL Compatible)
 
 =cut
-
-
-__END__
-
