@@ -1,13 +1,12 @@
 package Fey::SQL::Union;
-BEGIN {
-  $Fey::SQL::Union::VERSION = '0.40';
-}
 
 use strict;
 use warnings;
 use namespace::autoclean;
 
-use Moose;
+our $VERSION = '0.41';
+
+use Moose 0.90;
 
 with 'Fey::Role::SetOperation' => { keyword => 'UNION' };
 
@@ -17,7 +16,7 @@ with 'Fey::Role::SQL::Cloneable';
 
 # ABSTRACT: Represents a UNION operation
 
-
+__END__
 
 =pod
 
@@ -27,7 +26,7 @@ Fey::SQL::Union - Represents a UNION operation
 
 =head1 VERSION
 
-version 0.40
+version 0.41
 
 =head1 SYNOPSIS
 
@@ -72,14 +71,10 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2011 by Dave Rolsky.
+This software is Copyright (c) 2011 - 2015 by Dave Rolsky.
 
 This is free software, licensed under:
 
   The Artistic License 2.0 (GPL Compatible)
 
 =cut
-
-
-__END__
-
