@@ -1,24 +1,22 @@
 package Fey::SQL::Update;
-BEGIN {
-  $Fey::SQL::Update::VERSION = '0.40';
-}
 
 use strict;
 use warnings;
 use namespace::autoclean;
 
+our $VERSION = '0.41';
+
 use Fey::Exceptions qw( param_error );
 use Fey::Literal;
-use Fey::Types
-    qw( ArrayRef CanQuote ColumnWithTable NonNullableUpdateValue
-        NullableUpdateValue Table );
+use Fey::Types qw( ArrayRef CanQuote ColumnWithTable NonNullableUpdateValue
+    NullableUpdateValue Table );
 use overload ();
 use Scalar::Util qw( blessed );
 
-use Moose;
-use MooseX::Params::Validate qw( pos_validated_list );
-use MooseX::SemiAffordanceAccessor;
-use MooseX::StrictConstructor;
+use Moose 0.90;
+use MooseX::Params::Validate 0.08 qw( pos_validated_list );
+use MooseX::SemiAffordanceAccessor 0.03;
+use MooseX::StrictConstructor 0.07;
 
 with 'Fey::Role::SQL::HasOrderByClause', 'Fey::Role::SQL::HasLimitClause';
 
@@ -42,7 +40,7 @@ has '_update' => (
 has '_set_pairs' => (
     traits  => ['Array'],
     is      => 'bare',
-    isa     => ArrayRef[ArrayRef],
+    isa     => ArrayRef [ArrayRef],
     default => sub { [] },
     handles => {
         _add_set_pair => 'push',
@@ -150,14 +148,14 @@ sub set_clause {
         'SET ' . (
             join ', ',
             map {
-                my $val = $_->[1];
+                my $val     = $_->[1];
                 my $val_sql = $val->sql($dbh);
                 $val_sql = "($val_sql)"
                     if blessed $val
-                        && $val->can('does')
-                        && $val->does('Fey::Role::SQL::ReturnsData');
+                    && $val->can('does')
+                    && $val->does('Fey::Role::SQL::ReturnsData');
                 $self->$col_quote( $_->[0], $dbh ) . ' = ' . $val_sql;
-                } $self->_set_pairs()
+            } $self->_set_pairs()
         )
     );
 }
@@ -185,7 +183,7 @@ __PACKAGE__->meta()->make_immutable();
 
 # ABSTRACT: Represents a UPDATE query
 
-
+__END__
 
 =pod
 
@@ -195,7 +193,7 @@ Fey::SQL::Update - Represents a UPDATE query
 
 =head1 VERSION
 
-version 0.40
+version 0.41
 
 =head1 SYNOPSIS
 
@@ -323,14 +321,10 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2011 by Dave Rolsky.
+This software is Copyright (c) 2011 - 2015 by Dave Rolsky.
 
 This is free software, licensed under:
 
   The Artistic License 2.0 (GPL Compatible)
 
 =cut
-
-
-__END__
-
