@@ -1,17 +1,16 @@
 package Fey::SQL::Where;
-BEGIN {
-  $Fey::SQL::Where::VERSION = '0.40';
-}
 
 use strict;
 use warnings;
 use namespace::autoclean;
 
+our $VERSION = '0.41';
+
 use Fey::Types;
 
-use Moose;
-use MooseX::SemiAffordanceAccessor;
-use MooseX::StrictConstructor;
+use Moose 0.90;
+use MooseX::SemiAffordanceAccessor 0.03;
+use MooseX::StrictConstructor 0.07;
 
 with 'Fey::Role::SQL::HasWhereClause';
 
@@ -25,7 +24,7 @@ __PACKAGE__->meta()->make_immutable();
 
 # ABSTRACT: Represents a "stand-alone" WHERE clause
 
-
+__END__
 
 =pod
 
@@ -35,7 +34,7 @@ Fey::SQL::Where - Represents a "stand-alone" WHERE clause
 
 =head1 VERSION
 
-version 0.40
+version 0.41
 
 =head1 SYNOPSIS
 
@@ -82,14 +81,10 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2011 by Dave Rolsky.
+This software is Copyright (c) 2011 - 2015 by Dave Rolsky.
 
 This is free software, licensed under:
 
   The Artistic License 2.0 (GPL Compatible)
 
 =cut
-
-
-__END__
-
