@@ -1,23 +1,23 @@
 package Fey::Schema;
-BEGIN {
-  $Fey::Schema::VERSION = '0.40';
-}
 
 use strict;
 use warnings;
 use namespace::autoclean;
 
+our $VERSION = '0.41';
+
 use Fey::Exceptions qw( param_error );
 use Fey::NamedObjectSet;
 use Fey::SQL;
 use Fey::Table;
-use Fey::Types qw( FK HashRef NamedObjectSet Str Table TableLikeOrName TableOrName  );
+use Fey::Types
+    qw( FK HashRef NamedObjectSet Str Table TableLikeOrName TableOrName  );
 use Scalar::Util qw( blessed );
 
 use Moose 0.90;
-use MooseX::Params::Validate qw( pos_validated_list );
-use MooseX::SemiAffordanceAccessor;
-use MooseX::StrictConstructor;
+use MooseX::Params::Validate 0.08 qw( pos_validated_list );
+use MooseX::SemiAffordanceAccessor 0.03;
+use MooseX::StrictConstructor 0.07;
 
 has 'name' => (
     is       => 'rw',
@@ -209,7 +209,7 @@ __PACKAGE__->meta()->make_immutable();
 
 # ABSTRACT: Represents a schema and contains tables and foreign keys
 
-
+__END__
 
 =pod
 
@@ -219,7 +219,7 @@ Fey::Schema - Represents a schema and contains tables and foreign keys
 
 =head1 VERSION
 
-version 0.40
+version 0.41
 
 =head1 SYNOPSIS
 
@@ -328,14 +328,10 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2011 by Dave Rolsky.
+This software is Copyright (c) 2011 - 2015 by Dave Rolsky.
 
 This is free software, licensed under:
 
   The Artistic License 2.0 (GPL Compatible)
 
 =cut
-
-
-__END__
-
