@@ -1,12 +1,11 @@
 package Fey::Table;
-BEGIN {
-  $Fey::Table::VERSION = '0.40';
-}
 
 use strict;
 use warnings;
 use namespace::autoclean;
 
+our $VERSION = '0.41';
+
 use Fey::Column;
 use Fey::Exceptions qw( param_error );
 use Fey::NamedObjectSet;
@@ -18,10 +17,10 @@ use Fey::Types qw(
 use List::AllUtils qw( any all first_index );
 use Scalar::Util qw( blessed weaken );
 
-use Moose;
-use MooseX::Params::Validate qw( pos_validated_list );
-use MooseX::SemiAffordanceAccessor;
-use MooseX::StrictConstructor;
+use Moose 0.90;
+use MooseX::Params::Validate 0.08 qw( pos_validated_list );
+use MooseX::SemiAffordanceAccessor 0.03;
+use MooseX::StrictConstructor 0.07;
 use Moose::Util::TypeConstraints;
 
 with 'Fey::Role::TableLike';
@@ -52,7 +51,7 @@ has 'is_view' => (
 has '_keys' => (
     traits  => ['Array'],
     is      => 'bare',
-    isa     => ArrayRef[NamedObjectSet],
+    isa     => ArrayRef [NamedObjectSet],
     default => sub { [] },
     handles => {
         _keys       => 'elements',
@@ -83,7 +82,7 @@ has 'schema' => (
 
 has 'candidate_keys' => (
     is         => 'ro',
-    isa        => ArrayRef[ArrayRef[Column]],
+    isa        => ArrayRef [ ArrayRef [Column] ],
     clearer    => '_clear_candidate_keys',
     lazy_build => 1,
     init_arg   => undef,
@@ -93,7 +92,7 @@ after '_add_key', '_delete_key' => sub { $_[0]->_clear_candidate_keys() };
 
 has 'primary_key' => (
     is         => 'ro',
-    isa        => ArrayRef[Column],
+    isa        => ArrayRef [Column],
     clearer    => '_clear_primary_key',
     lazy_build => 1,
     init_arg   => undef,
@@ -304,6 +303,8 @@ sub sql {
     return $_[1]->quote_identifier( $_[0]->name() );
 }
 
+sub sql_for_select_clause { $_[0]->sql( $_[1] ) . '.*' }
+
 sub sql_with_alias { goto &sql }
 
 sub _build_id { $_[0]->name() }
@@ -314,7 +315,7 @@ __PACKAGE__->meta()->make_immutable();
 
 # ABSTRACT: Represents a table (or view)
 
-
+__END__
 
 =pod
 
@@ -324,7 +325,7 @@ Fey::Table - Represents a table (or view)
 
 =head1 VERSION
 
-version 0.40
+version 0.41
 
 =head1 SYNOPSIS
 
@@ -484,6 +485,8 @@ columns in table, in same order as returned by C<< $table->columns() >>.
 
 =head2 $table->sql_with_alias()
 
+=head2 $table->sql_for_select_clause()
+
 Returns the appropriate SQL snippet for the table.
 
 =head2 $table->id()
@@ -505,14 +508,10 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2011 by Dave Rolsky.
+This software is Copyright (c) 2011 - 2015 by Dave Rolsky.
 
 This is free software, licensed under:
 
   The Artistic License 2.0 (GPL Compatible)
 
 =cut
-
-
-__END__
-
