@@ -1,20 +1,19 @@
 package Fey::Table::Alias;
-BEGIN {
-  $Fey::Table::Alias::VERSION = '0.40';
-}
 
 use strict;
 use warnings;
 use namespace::autoclean;
 
+our $VERSION = '0.41';
+
 use Fey::Exceptions qw(param_error);
 use Fey::Table;
 use Fey::Types qw( Column HashRef Str Table );
 
-use Moose;
-use MooseX::Params::Validate qw( pos_validated_list );
-use MooseX::SemiAffordanceAccessor;
-use MooseX::StrictConstructor;
+use Moose 0.90;
+use MooseX::Params::Validate 0.08 qw( pos_validated_list );
+use MooseX::SemiAffordanceAccessor 0.03;
+use MooseX::StrictConstructor 0.07;
 
 with 'Fey::Role::TableLike';
 
@@ -39,7 +38,7 @@ has 'alias_name' => (
 has '_columns' => (
     traits  => ['Hash'],
     is      => 'bare',
-    isa     => HashRef[Column],
+    isa     => HashRef [Column],
     default => sub { {} },
     handles => {
         _get_column => 'get',
@@ -102,6 +101,10 @@ sub primary_key {
 
 sub is_alias {1}
 
+sub sql_for_select_clause {
+    return $_[1]->quote_identifier( $_[0]->alias_name() ) . '.*';
+}
+
 sub sql_with_alias {
     return (  $_[1]->quote_identifier( $_[0]->table()->name() ) . ' AS '
             . $_[1]->quote_identifier( $_[0]->alias_name() ) );
@@ -115,7 +118,7 @@ __PACKAGE__->meta()->make_immutable();
 
 # ABSTRACT: Represents an alias for a table
 
-
+__END__
 
 =pod
 
@@ -125,7 +128,7 @@ Fey::Table::Alias - Represents an alias for a table
 
 =head1 VERSION
 
-version 0.40
+version 0.41
 
 =head1 SYNOPSIS
 
@@ -194,6 +197,8 @@ Always returns true.
 
 =head2 $alias->sql_with_alias()
 
+=head2 $table->sql_for_select_clause()
+
 Returns the appropriate SQL snippet for the alias.
 
 =head2 $alias->id()
@@ -215,14 +220,10 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2011 by Dave Rolsky.
+This software is Copyright (c) 2011 - 2015 by Dave Rolsky.
 
 This is free software, licensed under:
 
   The Artistic License 2.0 (GPL Compatible)
 
 =cut
-
-
-__END__
-
