@@ -1,22 +1,20 @@
 package Fey::Types;
-BEGIN {
-  $Fey::Types::VERSION = '0.40';
-}
 
 use strict;
 use warnings;
 
 use base 'MooseX::Types::Combine';
 
+our $VERSION = '0.41';
+
 __PACKAGE__->provide_types_from(
-    qw( MooseX::Types::Moose Fey::Types::Internal )
-);
+    qw( MooseX::Types::Moose Fey::Types::Internal ));
 
 1;
 
 # ABSTRACT: Types for use in Fey
 
-
+__END__
 
 =pod
 
@@ -26,7 +24,7 @@ Fey::Types - Types for use in Fey
 
 =head1 VERSION
 
-version 0.40
+version 0.41
 
 =head1 DESCRIPTION
 
@@ -44,14 +42,10 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2011 by Dave Rolsky.
+This software is Copyright (c) 2011 - 2015 by Dave Rolsky.
 
 This is free software, licensed under:
 
   The Artistic License 2.0 (GPL Compatible)
 
 =cut
-
-
-__END__
-
